@@ -5,6 +5,6 @@ panelHorizontalStripes
 panelText:''
 panelText:'This is the DateTimePanel'
 panelText:''
-panelButton:'Sync Time with NTP' message:[['ntpdate' 'pool.ntp.org']|runCommandWithSudoInBackground]
+panelButton:'Sync Time with NTP' message:[['ntpdate' 'pool.ntp.org']|runCommandWithSudoAndReturnOutput|asString|showAlert]
 EOF
 
