@@ -33,7 +33,7 @@ fi
 
 # check if partition is vfat
 if ! blkid -s TYPE -o value "$BOOTDEVICE" | grep '^vfat$' >/dev/null ; then
-    echo "Error, partition is not vfat"
+    echo "Error, partition is not formatted as vfat"
     exit 1
 fi
 
@@ -45,7 +45,7 @@ if ! mount "$BOOTDEVICE" "$MOUNTPOINT" ; then
     exit 1
 fi
 
-cp -R -T /InstallerEFIBootloader "$MOUNTPOINT"
+cp -R -T /mntinstaller/InstallerEFIBootloader "$MOUNTPOINT"
 sed -i "s/__UUID__/$UUID/g" "$MOUNTPOINT/EFI/BOOT/syslinux.cfg"
 
 umount "$MOUNTPOINT"
