@@ -8,7 +8,7 @@ if (not $arg) {
 $date = `date "+%Y-%m-%d %H:%M"`;
 chomp $date;
 
-$base = "$ENV{'HOME'}/Screen Shot $date";
+$base = "$ENV{'HOME'}/Screenshot $date";
 $path = "$base.png";
 for ($i=0;;$i++) {
     if (-e $path) {
@@ -20,9 +20,9 @@ for ($i=0;;$i++) {
 
 system(qq{import -frame -window "$arg" "$path"});
 if ($? != 0) {
-    system(qq{echo "Unable to take screen shot" | hotdog alert});
+    system('hotdog', 'alert', 'Unable to take screen shot');
     exit 0;
 }
 
-system(qq{echo "'Screen shot is located at '$path'" | hotdog alert});
+system('hotdog', 'alert', "Screen shot is located at '$path'");
 
